@@ -571,6 +571,9 @@ void QWaylandDisplay::handleWindowDeactivated(QWaylandWindow *window)
 
     mActiveWindows.removeOne(window);
 
+    if (QCoreApplication::closingDown())
+        return;
+
     if (auto *decoration = window->decoration())
         decoration->update();
 }
@@ -631,7 +634,7 @@ void QWaylandDisplay::requestWaylandSync()
 
 QWaylandInputDevice *QWaylandDisplay::defaultInputDevice() const
 {
-    return mInputDevices.isEmpty() ? 0 : mInputDevices.first();
+    return mInputDevices.isEmpty() ? nullptr : mInputDevices.first();
 }
 
 #if QT_CONFIG(cursor)
